@@ -1,11 +1,10 @@
 from .bump import Bump
-from .commit import Commit
 from .check import Check
+from .commit import Commit
 from .example import Example
 from .info import Info
 from .list_cz import ListCz
 from .schema import Schema
 from .version import Version
 
-__all__ = ("Bump", "Check", "Commit", "Example", "Info", "ListCz", "Schema",
-           "Version")
+__all__ = ("Bump", "Check", "Commit", "Example", "Info", "ListCz", "Schema", "Version")
